###### Municipios de Origem e Destino ###########

# Atencao: Este script foi salvo criado com codificacao UTF-8.

# Essa funo tem como argumentos: direcao, produto e grupo. 
# direcao = (origem, destino)
# produto = (tora, acabado)
# grupo = (geral, grupo1, grupo2, grupo3)

# Pacotes usados
library(data.table)
library(dplyr)
library(tidyr)
library(ggplot2)
library(scales)
library(forcats) #para a funo fct_reorder()
library(stringi)
library(grid)
library(gridExtra)

#  L sisdof_tora
sisdof_tora <- fread("SisDOF-toras_2012_2017.csv",
                     colClasses = c("character", "character", "character",
                                    "character", "character", "character",
                                    "character", "character", "character",
                                    "character", "character", "character",
                                    "character", "character", "character",
                                    "character", "numeric", "numeric"))

# Deleta coluna V1 criada pelo comando fread.
sisdof_tora$V1 <- NULL

# L sisdof_produto
sisdof_produto <- fread("SisDOF_Destino_2012_2017.csv",
                        colClasses = c("character", "character", "character",
                                       "character", "character", "character",
                                       "character", "character", "character",
                                       "character", "character", "character",
                                       "character", "character", "character",
                                       "character", "numeric", "numeric"))

# Deleta coluna V1 criada pelo comando fread.
sisdof_produto$V1 <- NULL

#### Formatao dos nomes dos municpios ####

# Abre planilha com nomes de municipios do IBGE, obtida com o Gustavo Bediaga. Essa planilha est sem UF e coordenadas
municipios.ibge <- fread("municipios_ibge.csv") # obtida com o Gustavo Bediaga

# Abre planilha com nomes de municipios do IBGE que contem UF, Coordenadas e Codigo IBGE
municipios.ibge.uf <- fread("Municipios_Brasileiros_UF_Codigo.csv") # obtida em https://github.com/kelvins/Municipios-Brasileiros

# Renomeia colunas de municipios.ibge.uf
colnames(municipios.ibge.uf) <- c("Codigo.Ibge", "Nome.Municipio", "Codigo.UF",
                               "UF", "Estado", "Latitude", "Longitude")

# Fusiona as planilha municipios.ibge com municipios.ibge.uf. A ideia e pegar o nome dos municipios e o codigo com a planilha do Bediaga e pegar a UF e latitude e longituda da outra planilha
municipios.ibge <- merge(municipios.ibge, municipios.ibge.uf,
                         by.x = c("geocodigo"), 
               by.y = c("Codigo.Ibge"), all.x = TRUE)

# Apaga colunas desnecessarias
municipios.ibge <- municipios.ibge[,-(c("V1", "id", "nomeabrev", "geometriaaproximada",
                                        "anodereferencia", "id_objeto","Nome.Municipio"))]

## cria coluna na planilha municipios.ibge com os nomes dos municipios formatados conforme sisdof

# Ver numero nomes unicos de municipios
#length(unique(municipios.ibge$Nome.Municipio)) # resultado esperado: 5299, ou seja, ha 271 municipios com nomes identicos

# Nomes dos municipios com nomes identicos
#municipios.ibge$Nome.Municipio[duplicated(municipios.ibge$Nome.Municipio)]

# Todas para maiscula
municipios.ibge$Municipio.Sisdof <- toupper(municipios.ibge$nome)

# Elimina os acentos ortogrficos
municipios.ibge$Municipio.Sisdof <- stri_trans_general(municipios.ibge$Municipio.Sisdof, 
                                                       "Latin-ASCII")

# Troca espaos por "."
municipios.ibge$Municipio.Sisdof <- gsub("\\s+", ".", municipios.ibge$Municipio.Sisdof)

# Deleta "." no final, se houver
# grep("\\.$", municipios.ibge$Municipio.Sisdof)   #Testa se h municpios com "." no final, caso positivo executar o comando abaixo:
municipios.ibge$Municipio.Sisdof <- gsub("\\.$", "", municipios.ibge$Municipio.Sisdof)

# Cria a coluna Municipio.UF com a fusao do nome do municpio ao Estado
municipios.ibge$Municipio.UF <- paste(municipios.ibge$nome,
                                      municipios.ibge$UF,
                                      sep = "-")

# fusiona sisdof_tora e sisdof_produto
sisdof <- rbind(sisdof_produto, sisdof_tora)

# Cria um subset de sisdof com os nomes dos Municipios.Origen de sisdof que no estao em municipios.ibge
x <- subset(sisdof$Municipio.Origem,
            !(sisdof$Municipio.Origem %in% municipios.ibge$Municipio.Sisdof))

x <- unique(x)

# Cria o subset sisdof.dif para identificar os codigos do IBGE dos municipios com nomes que nao estavam na planilha do IBGE
#sisdof.dif <- sisdof[Municipio.Destino == "SAO.LUIZ.DO.ANUAA" |
#                                    sisdof$Municipio.Origem == "SAO.LUIZ.DO.ANUAA"]

#unique(sisdof.dif$UF.Origem[sisdof.dif$Municipio.Origem == "SAO.LUIZ.DO.ANUAA"])
#unique(sisdof.dif$UF.Destino[sisdof.dif$Municipio.Destino == "SAO.LUIZ.DO.ANUAA"])


# Lista de municipios divergentes:
# "ITAPAGE" = Itapaj-CE
#"SANTANA.DO.LIVRAMENTO" = Sant' Ana do Livramento-RS
# "PICARRAS" = Balnerio Piarras-SC
# "PAU.DARCO" = Pau D'arco-PA
# "SAO.LUIZ.DO.ANUAA" = So Luiz-RR

# Altera manualmente os nomes dos Municipios.Origem divergentes em sisdof_tora
sisdof_tora$Municipio.Origem[sisdof_tora$Municipio.Origem == "ITAPAGE"] <- "Itapaj"
sisdof_tora$Municipio.Origem[sisdof_tora$Municipio.Origem == "SANTANA.DO.LIVRAMENTO"] <- "Sant' Ana do Livramento"
sisdof_tora$Municipio.Origem[sisdof_tora$Municipio.Origem == "PICARRAS"] <- "Balnerio Piarras"
sisdof_tora$Municipio.Origem[sisdof_tora$Municipio.Origem == "PAU.DARCO"] <- "Pau D'arco"
sisdof_tora$Municipio.Origem[sisdof_tora$Municipio.Origem == "SAO.LUIZ.DO.ANUAA"] <- "So Luiz"

# Altera manualmente os nomes dos Municipios.Destino divergentes em sisdof_tora
sisdof_tora$Municipio.Destino[sisdof_tora$Municipio.Destino == "ITAPAGE"] <- "Itapaj"
sisdof_tora$Municipio.Destino[sisdof_tora$Municipio.Destino == "SANTANA.DO.LIVRAMENTO"] <- "Sant' Ana do Livramento"
sisdof_tora$Municipio.Destino[sisdof_tora$Municipio.Destino == "PICARRAS"] <- "Balnerio Piarras"
sisdof_tora$Municipio.Destino[sisdof_tora$Municipio.Destino == "PAU.DARCO"] <- "Pau D'arco"
sisdof_tora$Municipio.Destino[sisdof_tora$Municipio.Destino == "SAO.LUIZ.DO.ANUAA"] <- "So Luiz"

# Altera manualmente os nomes dos Municipios.Origem divergentes em sisdof_produto
sisdof_produto$Municipio.Origem[sisdof_produto$Municipio.Origem == "ITAPAGE"] <- "Itapaj"
sisdof_produto$Municipio.Origem[sisdof_produto$Municipio.Origem == "SANTANA.DO.LIVRAMENTO"] <- "Sant' Ana do Livramento"
sisdof_produto$Municipio.Origem[sisdof_produto$Municipio.Origem == "PICARRAS"] <- "Balnerio Piarras"
sisdof_produto$Municipio.Origem[sisdof_produto$Municipio.Origem == "PAU.DARCO"] <- "Pau D'arco"
sisdof_produto$Municipio.Origem[sisdof_produto$Municipio.Origem == "SAO.LUIZ.DO.ANUAA"] <- "So Luiz"

# Altera manualmente os nomes dos Municipios.Destino divergentes em sisdof_produto
sisdof_produto$Municipio.Destino[sisdof_produto$Municipio.Destino == "ITAPAGE"] <- "Itapaj"
sisdof_produto$Municipio.Destino[sisdof_produto$Municipio.Destino == "SANTANA.DO.LIVRAMENTO"] <- "Sant' Ana do Livramento"
sisdof_produto$Municipio.Destino[sisdof_produto$Municipio.Destino == "PICARRAS"] <- "Balnerio Piarras"
sisdof_produto$Municipio.Destino[sisdof_produto$Municipio.Destino == "PAU.DARCO"] <- "Pau D'arco"
sisdof_produto$Municipio.Destino[sisdof_produto$Municipio.Destino == "SAO.LUIZ.DO.ANUAA"] <- "So Luiz"

# Fusiona o nome do Municipio.Sisdof com a UF.
municipios.ibge$Municipio.Sisdof <- paste0(municipios.ibge$Municipio.Sisdof, 
                                           "-",
                                           municipios.ibge$UF)

# Apaga variaveis intermediarias
rm(sisdof, municipios.ibge.uf, x)

#### Funcao para gerar graficos ####

municipio <- function (direcao, grupo) {
    # direcao = (origem, destino). Origem, implica tora. Destino, implica produto acabado.
    # grupo = (geral, grupo1, grupo2, grupo3)
    
    # geral = todas as espcies 
    # grupo1 = especies de grande movimentacao
    # grupo2 = ameacadas (Portaria 443)
    # grupo3 = cites
    
    # Funo para passar apenas a primeira letra de uma palavra para maiscula
    capFirst <- function(s) {
        paste(toupper(substring(s, 1, 1)), substring(s, 2), sep = "")
    }
    
    # Ttulos do grfico
    titulo.grupo <- capFirst(grupo)
    #g.sub.titulo <- "Volume relativo produ de 2012 a 2017 (%)"
    
    # Dimensoes do Grafico
    #largura <- 10.3
    texto <- 21.87
    bola <- 25.5
    
    if (direcao == "origem") {
        
        # Muda diretrio de trabalho para o de Toras. Cria o diretorio se ja nao existir.
        
        ifelse(!dir.exists(file.path("Figuras", 
                                     "1.1.Toras", 
                                     "1.1.4.Municipio.Origem")),
               dir.create(file.path("Figuras", 
                                    "1.1.Toras", 
                                    "1.1.4.Municipio.Origem"),
                          recursive = TRUE),
               FALSE)
        
        setwd(file.path("Figuras", 
                        "1.1.Toras", 
                        "1.1.4.Municipio.Origem"))
        
        
        # sisdof =  sisdof_tora. Origem, implica tora
        sisdof <- sisdof_tora
        
        # Legendas dos grficos a serem gerados
        direcao <- "Municipio.Origem"
        UF <- "UF.Origem"
        g.titulo <- "Municpios Produtores de Madeira"  # Titulo do grafico
        g.sub.titulo <- "Volume relativo produzido de 2012 a 2017 (%)"
        
        # Cores do Grafico: Tons azuis 
        cor_segmento <- "lightskyblue"                # cor da linha   
        cor_ponto <- "navy"                   # cor do ponto
        
    } else if (direcao == "destino") {
        
        ifelse(!dir.exists(file.path("Figuras", 
                                     "1.2.Produto.Acabado", 
                                     "1.2.4.Municipio.Destino")),
               dir.create(file.path("Figuras", 
                                    "1.2.Produto.Acabado", 
                                    "1.2.4.Municipio.Destino"),
                          recursive = TRUE),
               FALSE)
        
        setwd(file.path("Figuras", 
                        "1.2.Produto.Acabado", 
                        "1.2.4.Municipio.Destino"))
        
        # sisdof = sisdof_produto. Destino, implica produto acabado.
        sisdof <- sisdof_produto
        sisdof <- sisdof[sisdof$Pais.Destino == "BRASIL"]
        
        # Legendas dos grficos a serem gerados
        direcao <- "Municipio.Destino"
        UF <- "UF.Destino"
        g.titulo <- "Municpios Consumidores de Produtos Madeireiros"   # Primeiro titulo do grafico
        g.sub.titulo <- "Volume relativo consumido de 2012 a 2017 (%)"
        
        # Cores do Grafico: Tons vermelhos 
        cor_segmento <- "salmon"                    # cor da linha   
        cor_ponto <- "firebrick4"                   # cor do ponto
        
    } 
    
    if ( grupo == "geral") {
        
        y <- sisdof
        g.sub.titulo.grupo <- "Todas as espcies"
    
    } else if (grupo == "grupo1") {
        
        lista_especies <- unique(sisdof[sisdof$Grupo == "Grupo.1"]$Especie)   # lista os nomes das espcies contidas no grupo 1
        y <- sisdof[sisdof$Grupo == "Grupo.1"]                            # subset com as espcies do grupo 1
        g.sub.titulo.grupo <- "25 Espcies de maior produo madeireira"
        
    } else if (grupo == "grupo2") {
        
        lista_especies <- unique(sisdof[sisdof$Grupo == "Grupo.2"]$Especie)   # lista os nomes das espcies contidas no grupo 2
        y <- sisdof[!is.na(sisdof$Portaria.443)]                         # subset com as espcies da portaria 443 e que nao estao nos grupos 1 ou 3
        g.sub.titulo.grupo <- "Espcies ameaadas de extino"
                         
    } else if (grupo == "grupo3") {
        
        lista_especies <- unique(sisdof[sisdof$Grupo == "Grupo.3"]$Especie)   # lista os nomes das espcies contidas no grupo 3
        y <- sisdof[!is.na(sisdof$Cites)]                                 # subset com as espcies da portaria 443 e que nao estao nos grupos 1 ou 3
        g.sub.titulo.grupo <- "Espcies CITES"
                         
        
    }
    
    ## Faz o grfico dos grupos
    
    # Cria subset, excluindo as movimentaes para o exterior, mantendo apenas aquelas com 
    # valores "Brasil" para a coluna Pais.Destino 
    agregado <- y[y$Pais.Destino == "BRASIL"]
    
    # Elimina o ms, mantendo apenas o ano
    #y$Emissao <- as.numeric(sub("^[0-9]+-", "", y$Emissao))
    
    # Agrega de acordo com o municipio de origem/destino e UF de origem/destino
    agregado <- y[, .(sum(Volume.Total)),
                  by = .(y[[direcao]],
                         y[[UF]])]
    
    # Cria a coluna volume percentual
    agregado$Volume.Percentual <- agregado$V1/sum(agregado$V1)*100 
    
    # Renomeia as colunas V1 e V2  
    colnames(agregado) <- c(direcao, UF, "Volume.Total", "Volume.Percentual")
    
    # Para o grafico entender que  pra ordenar pelo Volume.Percentual
    agregado[[direcao]] <- factor(agregado[[direcao]], 
                                              levels = unique(agregado[[direcao]])[order(agregado$Volume.Percentual, 
                                                                                                     decreasing = TRUE)])
    
    # Ordena de forma crescente em relao ao Volume.Percentual
    agregado <- agregado[order(agregado$Volume.Percentual, decreasing = TRUE),]
        
    # Seleciona no mximo 10 municipios
    
    if (length(unique(agregado[[direcao]])) >= 10) {
        
        agregado <- agregado[1:10,]
        
        } else {
        
        agregado <- agregado[1:length(unique(agregado[[direcao]])),]
        
        } 
    
    # modifica os nomes dos municipios a serem mostrados no grafico
    agregado[[direcao]] <- paste0(agregado[[direcao]],
                                  "-",
                                  agregado[[UF]])
    
    x <- match(agregado[[direcao]], 
               municipios.ibge$Municipio.Sisdof)   # procura os nomes das especies de sisdof1 que esto presentes em nomes.diferentes$Especie.Sisflora. O resultado  o objeto x no qual iro aparecer as posies em nomes.diferentes$Especie.Sisflora que possuem nomes de especies de sisdof1$Especie 
    x <- x[!is.na(x)]                               # esse comando elimina de x os NAs. Dessa forma, x contm as posies em nomes.diferentes$Especie.Sisflora das especies de sisdof1$Especies com nomes escritos de forma errada e que devem ser substituido pelos nomes contidos em nomes.diferentes$Especie.Resolvida
    
    agregado[[direcao]] <-  municipios.ibge$Municipio.UF[x]  # 
    
    # Largura do grafico. Varia de acordo com o tamanho do titulo ou subtitulo. Como a fonte do titulo e 10% maior do que a do subtitulo, multiplicamos por 1.11.
    
    largura <- data.table(tipo = c("g.titulo", "lista.especie", "g.sub.titulo", "municipio"),
                          valor = c(nchar(g.titulo), 
                                    nchar(g.sub.titulo.grupo),
                                    nchar(g.sub.titulo),
                                    2*max(nchar(as.character(agregado[[direcao]])), na.rm = TRUE)))
    
    largura <- max(largura$valor, na.rm = TRUE)
    
    # Altura do grafico. Varia conforme o numero de municipios.
    altura <- 1.6 + (0.8*length(agregado[[direcao]]))
    
    if (length(agregado[[direcao]]) != 0) {
        
    # Para ordenar as barras de forma decrescente quando o grafico fica deitado.
    agregado <- mutate(agregado,  nova.direcao = fct_reorder(agregado[[direcao]],
                                                       agregado$Volume.Percentual))
    
    gplot <- ggplot(agregado, aes(agregado$nova.direcao,
                                  agregado$Volume.Percentual)) +
        geom_segment(aes(x = agregado$nova.direcao, 
                         y = 0, 
                         xend = agregado$nova.direcao, 
                         yend = agregado$Volume.Percentual),
                     position = position_dodge(width = 0.8),
                     color = cor_segmento,
                     size = bola/3) +
        geom_point(size = bola,
                   color = cor_ponto,
                   position = position_dodge(width = 0.8))+
        scale_y_continuous(limits=c(0, 1.1*max(agregado$Volume.Percentual)), oob=rescale_none)+
        geom_text(aes(label = format(round(Volume.Percentual, 2),     # texto do Volume.Percentual
                                     big.mark = ".", 
                                     decimal.mark = ",")),
                  color = "white", 
                  size = 0.3*texto,
                  fontface = "bold")+
        theme(plot.title = element_text(lineheight = 0.1, 
                                        face = "bold",
                                        hjust = 0.5,
                                        size = 1.3*texto),
              plot.subtitle = element_text(lineheight = 0.4, 
                                           face = "bold",
                                           hjust = 0.5,
                                           size = 1.17*texto),
              axis.title.y = element_blank(),
              axis.text.y = element_text(size = 1.1*texto,
                                         color = cor_ponto,
                                         face = "bold",
                                         hjust = 0),
              axis.title.x = element_blank(),
              axis.text.x = element_blank(),
              axis.ticks.x = element_blank(),
              axis.ticks.y = element_blank(),
              panel.background = element_blank(),
              panel.grid.major = element_blank(), 
              panel.grid.minor = element_blank())+
        coord_flip()
    
    # Abre para gravacao em PDF
    pdf(paste0("#", titulo.grupo, "_", direcao, ".pdf"), 
        width = largura/3.75, 
        height = altura)
    
    grid.arrange(
        gplot,
        nrow = 1,
        top = textGrob(paste0(g.titulo,
                              "\n",
                              g.sub.titulo.grupo,
                              "\n",
                              g.sub.titulo),
                       gp = gpar(fontface = 2, 
                                 fontsize = 26,
                                 lineheight = 0.8)))
    
# Fecha o PDF
    dev.off()
    
    }
    
## Faz os grficos para cada uma das espcies da lista dos grupos 1, 2 ou 3.
    
    if (grupo == "grupo1" | grupo == "grupo2" | grupo == "grupo3") {
        
        for (i in 1:length(lista_especies)) {
            especie <- y[y$Especie == lista_especies[i]]
            
            # Agrega de acordo com o municipio de origem e UF.Origem
            especie <- especie[, .(sum(Volume.Total)),
                        by = .(especie[[direcao]],
                               especie[[UF]])]
            
            # Cria a coluna volume percentual
            especie$Volume.Percentual <- especie$V1/sum(especie$V1)*100 
            
            # Renomeia as colunas V1 e V2  
            colnames(especie) <- c(direcao, UF, "Volume.Total", "Volume.Percentual")
            
            # Para o grafico entender que  pra ordenar pelo Volume.Total
            especie[[direcao]] <- factor(especie[[direcao]], 
                                         levels = unique(especie[[direcao]])[order(especie$Volume.Percentual, 
                                                                                   decreasing = TRUE)])
            
            # Ordena de forma crescente em relao a data
            especie <- especie[order(especie$Volume.Percentual, decreasing = TRUE),]
        
            # Seleciona no mximo 10 municipios
            
            if (length(unique(especie[[direcao]])) >= 10) {
                
                especie <- especie[1:10,]
                
                }   else {
                
                especie <- especie[1:length(unique(especie[[direcao]])),]
                
                }
            
            # modifica os nomes dos municipios a serem mostrados no grafico
            
            especie[[direcao]] <- paste0(especie[[direcao]],
                                               "-",
                                               especie[[UF]])
            
            x <- match(especie[[direcao]], 
                       municipios.ibge$Municipio.Sisdof)   # procura os nomes das especies de sisdof1 que esto presentes em nomes.diferentes$Especie.Sisflora. O resultado  o objeto x no qual iro aparecer as posies em nomes.diferentes$Especie.Sisflora que possuem nomes de especies de sisdof1$Especie 
            
            x <- x[!is.na(x)]                               # esse comando elimina de x os NAs. Dessa forma, x contm as posies em nomes.diferentes$Especie.Sisflora das especies de sisdof1$Especies com nomes escritos de forma errada e que devem ser substituido pelos nomes contidos em nomes.diferentes$Especie.Resolvida
            
            especie[[direcao]] <-  municipios.ibge$Municipio.UF[x]  # essa funcao deu erro com a especie  "Astronium lecointei" pois a cidade de Paraty apareceu nos dados do DOF e Sisflora como Parati. A nomenclatura Paraty  a presente no Ibge
            
            # Largura do grafico.
            largura <- data.table(tipo = c("g.titulo", "lista.especie", "g.sub.titulo"),
                                  valor = c(nchar(g.titulo), 
                                            nchar(lista_especies[i]),
                                            nchar(g.sub.titulo),
                                            2*max(nchar(as.character(especie[[direcao]])), na.rm = TRUE)))
            largura <- max(largura$valor, na.rm = TRUE)
            
            # Altura do grafico
            altura <- 1.6 + (0.8*length(especie[[direcao]]))
            
            if (length(especie[[direcao]]) != 0) {
            
            # Para ordenar as barras de forma decrescente quando o grafico fica deitado.
            especie <- mutate(especie,  nova.direcao = fct_reorder(especie[[direcao]],
                                                                   especie$Volume.Percentual))
            
            # grafico
            
            gplot <- ggplot(especie, aes(especie$nova.direcao,
                                          especie$Volume.Percentual)) +
                geom_segment(aes(x = especie$nova.direcao, 
                                 y = 0, 
                                 xend = especie$nova.direcao, 
                                 yend = especie$Volume.Percentual),
                             position = position_dodge(width = 0.8),
                             color = cor_segmento,
                             size = bola/3) +
                geom_point(size = bola,
                           color = cor_ponto,
                           position = position_dodge(width = 0.8))+
                scale_y_continuous(limits=c(0, 1.1*max(especie$Volume.Percentual)), oob=rescale_none)+
                geom_text(aes(label = format(round(Volume.Percentual, 2),     # texto do Volume.Percentual
                                             big.mark = ".", 
                                             decimal.mark = ",")),
                          color = "white", 
                          size = 0.3*texto,
                          fontface = "bold")+
                theme(plot.title = element_text(lineheight = 0.1, 
                                                face = "bold",
                                                hjust = 0.5,
                                                size = 1.3*texto),
                      plot.subtitle = element_text(lineheight = 0.4, 
                                                   face = "bold",
                                                   hjust = 0.5,
                                                   size = 1.17*texto),
                      axis.title.y = element_blank(),
                      axis.text.y = element_text(size = 1.1*texto,
                                                 color = cor_ponto,
                                                 face = "bold",
                                                 hjust = 0),
                      axis.title.x = element_blank(),
                      axis.text.x = element_blank(),
                      axis.ticks.x = element_blank(),
                      axis.ticks.y = element_blank(),
                      panel.background = element_blank(),
                      panel.grid.major = element_blank(), 
                      panel.grid.minor = element_blank())+
                coord_flip()
            
        # Abre para gravacao em PDF
        pdf(paste0(titulo.grupo,"_", 
                   lista_especies[i],
                   "_",
                   direcao,
                   ".pdf"), 
            width = largura/3.75, 
            height = altura)
        
        grid.arrange(
            gplot,
            nrow = 1,
            top = textGrob(paste0(g.titulo,
                                  "\n",
                                  lista_especies[i],
                                  "\n",
                                  g.sub.titulo),
                           gp = gpar(fontface = 2, 
                                     fontsize = 26,
                                     lineheight = 0.8)))
    
        # Fecha o PDF
        dev.off()
        
            }
            
        }
        
        }
    
    setwd("..")
    setwd("..")
    setwd("..")
    
    }

municipio("origem", "geral")
municipio("origem", "grupo1")
municipio("origem", "grupo2")
municipio("origem", "grupo3")

municipio("destino", "geral")
municipio("destino", "grupo1")
municipio("destino", "grupo2")
municipio("destino", "grupo3")
    
   
    
    